import axios from "axios";
import iview from "view-design";
import router from "../router";

var service = axios.create({
  baseURL: process.env.BASE_API,
  timeout: 10000
});
//添加请求拦截器
service.interceptors.request.use(
  config => {
    const token = localStorage.getItem("token");
    if (token) {
      config.headers.common["Token"] = "Bearer " + token;
    }
    return config;
  },
  function(error) {
    return Promise.reject(error);
  }
);
//添加响应拦截器
service.interceptors.response.use(
  function(res) {
    const { data, headers } = res;
    if (headers.token) {
      localStorage.setItem("token", headers.token);
    }

    // 获取文件的条件下
    if (headers["content-disposition"]) {
      return { file: data, fileName: headers["content-disposition"] };
    }
    const { code } = data;
    const { msg } = data;
    switch (code) {
      case 1:
        return data;
      case 2:
        iview.Notice.error({
          title: "错误",
          desc: msg
        });
        localStorage.removeItem("token");
        router.push("/");
        return data;
      case 3:
        // iview.Message.error(msg);
        iview.Notice.error({
          title: "错误",
          desc: msg
        });
        return data;
      case 999:
        iview.Notice.error({
          title: "错误",
          desc: "服务器错误，请重试！ "
        });
        return data;
      default:
        return res;
    }
  },
  function(error) {
    console.log("err" + error);
    iview.Message.error("服务器错误，请重试！");
    return Promise.reject(error);
  }
);

export default service;
