import store from "@/store";
const { dispatch } = store;
import { Timing } from "@/components/index.js";
import {levelOption} from "@/libs/constants.js";

export default {
  components: { Timing, levelOption },
  data() {
    return {
      visible: false,
      submitLoading: false,
      company: null,
      levelOption: levelOption,

      saveCompanyRule: {
        name: [{ required: true, message: "请输入企业名称", trigger: "blur" }],
        contactName: [{ required: true, message: "请输入联系人", trigger: "blur" }],
        contactPhone: [{ required: true, message: "请输入联系电话", trigger: "blur" }],
      },
      companyForm: {
        id: 0,
        name: null,
        abbr: null,
        address: null,
        contactName: null,
        contactPhone: null,
        expiredDate: null,
        level: null,
      }
    };
  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      if (show) {
        this.$refs.companyForm.resetFields();

        this.companyForm.id = this.company.id;
        this.companyForm.name = this.company.name;
        this.companyForm.abbr = this.company.abbr;
        this.companyForm.address = this.company.address;
        this.companyForm.contactName = this.company.contactName;
        this.companyForm.contactPhone = this.company.contactPhone;
        this.companyForm.level = this.company.level;
      }
    },
  },
  methods: {
    saveCompany() {
      this.$refs.companyForm.validate(valid => {
        if (valid) {
          this.submitLoading = true;
          const requestData = {
            id: this.companyForm.id,
            name: this.companyForm.name,
            abbr: this.companyForm.abbr,
            address: this.companyForm.address,
            contactName: this.companyForm.contactName,
            contactPhone: this.companyForm.contactPhone,
            expiredDate: this.companyForm.expiredDate,
            level: this.companyForm.level,
          }
          dispatch("invoke/asyncUpdateCompany", requestData).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("修改成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    }
  },
  mounted() {
  }
};
