import store from "@/store";
const { dispatch } = store;
import { columns } from "./helper.js";
import { depositStatusOption } from "@/libs/constants.js";
import SignContract from "../sign/index.vue";
import EditContract from "../edit/index.vue";
import EditVehicle from "@/view/vehicle/edit/index.vue";
import ReturnDeposit from "./return_deposit/index.vue";
import EditDriver from "@/view/driver/edit/index.vue";


export default {
  components: { depositStatusOption, SignContract, EditContract, EditVehicle, ReturnDeposit, EditDriver },
  data() {
    return {
      loading: false,
      columns: [], 
      sources: [],
      depositStatusOption: depositStatusOption,
      vehicleInfo: "",
      driverInfo: "",
      sourceId: 0,
      status: null,
      depositStatus: null,
      type: 2,

      changeCurrent: 1,
      data: {
        total:0,
        current: 1,
        records:[],
      },
      page: {
        size: 10,
      },
    }
  },
  methods: {
    search(current = 1) {  
      this.searchForm = {
        type: this.type,
        vehicleInfo: this.vehicleInfo,
        driverInfo: this.driverInfo,
        sourceId: this.sourceId,
        status: this.status,
        depositStatus: this.depositStatus,
      };

      this.loading = true
      const initQuery = {
        current,
        size: this.page.size,
        records: this.searchForm
      };
      dispatch("invoke/asyncListContract", {
        ...initQuery
      }).then(({ data }) => {
        this.loading = false
        if (data != null) {
          this.data = {...data};
        } else {
          this.data = {
            total:0,
            current: 1,
            records:[],
          };
        }
      });
    },
    changePage(current) {
      this.search(current);
      this.changeCurrent = current
    },
    changeSize(value) { 
      this.page.size = value
      this.search();
    },
    showContract(contract, readonly) {
      this.$refs.editContract.contract = contract;
      this.$refs.editContract.readonly = readonly;
      this.$refs.editContract.visible = true;
    },
    showReturnDeposit(contract) {
      this.$refs.returnDeposit.contract = contract;
      this.$refs.returnDeposit.visible = true;
    },
    showVehicle(vehicle) {
      this.$refs.editVehicle.vehicle = vehicle;
      this.$refs.editVehicle.readonly = true;
      this.$refs.editVehicle.visible = true;
    },
    showDriver(driver) {
      this.$refs.editDriver.driver = driver;
      this.$refs.editDriver.readonly = true;
      this.$refs.editDriver.visible = true;
    },
    listSource() {
      dispatch("invoke/asyncListSource", {}).then(({ data }) => {
        this.loading = false;
        if (data == null) {
          return;
        }
        this.sources = data;
      });
    }
  },
  mounted() {
    this.listSource();
    this.columns = columns(this.search, this.showContract, this.showVehicle, this.showReturnDeposit, this.showDriver);
    this.search();
  }
};
