import store from "@/store";
const { dispatch } = store;
import { isInteger } from "@/libs/validator.js";
import { depositStatusOption } from "@/libs/constants.js";

export default {
  components: {  },
  data() {
    return {
      contract: null,
      visible: false,
      submitLoading: false,
      returnFormRule: {
        returnAmount: [{ required: true, message: "请输入返还金额", trigger: "blur" }, { validator: isInteger, trigger: "blur" } ],
      },
      returnForm: {
        plateNo: null,
        depositStatus: null,
        payableDepositAmount: null,
        paidDepositAmount: null,
        returnDepositAmount: null,
        returnAmount: null,
        remark: null,
      },
    };
  },
  computed: {
  },
  watch: {
    visible(show) {
      this.submitLoading = false;
      this.$refs.returnForm.resetFields();
      this.returnForm.plateNo = null;
      this.returnForm.depositStatus = null;
      this.returnForm.payableDepositAmount = null;
      this.returnForm.paidDepositAmount = null;
      this.returnForm.returnDepositAmount = null;
      this.returnForm.returnAmount = null;
      this.returnForm.remark = null;

      if(show) {
        this.returnForm.plateNo = this.contract.vehicleVo.plateNo;
        this.returnForm.payableDepositAmount = this.contract.payableDepositAmount;
        this.returnForm.paidDepositAmount = this.contract.paidDepositAmount;
        this.returnForm.returnDepositAmount = this.contract.returnDepositAmount;
        this.returnForm.depositStatus = depositStatusOption.filter(item => item.value === this.contract.depositStatus)[0].text;
      }
    },
  },
  methods: {
    setAll() {
      this.returnForm.returnAmount = "" + (this.returnForm.paidDepositAmount - this.returnForm.returnDepositAmount);
    },
    saveReturnDeposit() {
      this.$refs.returnForm.validate(valid => {
        if (valid) {
          const requestData = {
            contractId: this.contract.id,
            returnAmount: this.returnForm.returnAmount,
            remark: this.returnForm.remark,
          }
          dispatch("invoke/asyncReturnDeposit", requestData).then(({ code }) => {
            this.submitLoading = false;
            if (code === 1) {
              this.$Message.success("返还成功");
              this.$emit("search");
              this.visible = false;
            }
          });
        }
      });
    },
  },
  mounted() {
  }
};
